@@ -1,13 +1,10 @@
 .NAMES = LETTERS[c(1:8, 10:26)]
-setClass("doeFactor", representation = representation(low = "ANY", 
-    high = "ANY", name = "character", unit = "character", type = "character"), 
-    prototype = prototype(low = -1, high = 1, name = "", unit = "", 
-        type = "numeric"))
+setClass("doeFactor", representation = representation(low = "ANY", high = "ANY", name = "character", unit = "character", 
+    type = "character"), prototype = prototype(low = -1, high = 1, name = "", unit = "", type = "numeric"))
 setGeneric(".low", function(object) standardGeneric(".low"))
 setGeneric(".low<-", function(x, value) standardGeneric(".low<-"))
 setMethod(".low", "doeFactor", function(object) unlist(object@low))
-setReplaceMethod(".low", "doeFactor", function(x, 
-    value) {
+setReplaceMethod(".low", "doeFactor", function(x, value) {
     boolOld = is.numeric(.low(x))
     x@low <- value
     boolNew = is.numeric(.low(x))
@@ -21,8 +18,7 @@ setReplaceMethod(".low", "doeFactor", function(x,
 setGeneric(".high", function(object) standardGeneric(".high"))
 setGeneric(".high<-", function(x, value) standardGeneric(".high<-"))
 setMethod(".high", "doeFactor", function(object) unlist(object@high))
-setReplaceMethod(".high", "doeFactor", function(x, 
-    value) {
+setReplaceMethod(".high", "doeFactor", function(x, value) {
     boolOld = is.numeric(.high(x))
     x@high <- value
     boolNew = is.numeric(.high(x))
@@ -34,48 +30,41 @@ setReplaceMethod(".high", "doeFactor", function(x,
     return(x)
 })
 code2real = function(low, high, codedValue) {
-    return((diff(c(low, high))/2) * codedValue + mean(c(low, 
-        high)))
+    return((diff(c(low, high))/2) * codedValue + mean(c(low, high)))
 }
 code2real(10, 20, -1)
 setGeneric(".type", function(object) standardGeneric(".type"))
 setGeneric(".type<-", function(x, value) standardGeneric(".type<-"))
 setMethod(".type", "doeFactor", function(object) object@type)
-setReplaceMethod(".type", "doeFactor", function(x, 
-    value) {
+setReplaceMethod(".type", "doeFactor", function(x, value) {
     x@type <- value
     x
 })
 setGeneric(".unit", function(object) standardGeneric(".unit"))
 setGeneric(".unit<-", function(x, value) standardGeneric(".unit<-"))
 setMethod(".unit", "doeFactor", function(object) object@unit)
-setReplaceMethod(".unit", "doeFactor", function(x, 
-    value) {
+setReplaceMethod(".unit", "doeFactor", function(x, value) {
     x@unit <- value
     x
 })
 setMethod("names", "doeFactor", function(x) {
     x@name
 })
-setReplaceMethod("names", "doeFactor", function(x, 
-    value) {
+setReplaceMethod("names", "doeFactor", function(x, value) {
     x@name <- value
     x
 })
-setMethod("show", signature(object = "doeFactor"), 
-    function(object) {
-        cat("Name: ", names(object), "\n")
-        cat("low Setting: ", .low(object), "\n")
-        cat("high setting: ", .high(object), "\n")
-        cat("Unit: ", .unit(object), "\n")
-        cat("type: ", .type(object), "\n")
-        cat("\n")
-    })
-setClass(Class = "facDesign", representation = representation(name = "character", 
-    factors = "list", cube = "data.frame", star = "data.frame", 
-    centerCube = "data.frame", centerStar = "data.frame", generator = "ANY", 
-    response = "data.frame", block = "data.frame", blockGen = "data.frame", 
-    runOrder = "data.frame", standardOrder = "data.frame", desireVal = "list", 
+setMethod("show", signature(object = "doeFactor"), function(object) {
+    cat("Name: ", names(object), "\n")
+    cat("low Setting: ", .low(object), "\n")
+    cat("high setting: ", .high(object), "\n")
+    cat("Unit: ", .unit(object), "\n")
+    cat("type: ", .type(object), "\n")
+    cat("\n")
+})
+setClass(Class = "facDesign", representation = representation(name = "character", factors = "list", cube = "data.frame", 
+    star = "data.frame", centerCube = "data.frame", centerStar = "data.frame", generator = "ANY", response = "data.frame", 
+    block = "data.frame", blockGen = "data.frame", runOrder = "data.frame", standardOrder = "data.frame", desireVal = "list", 
     desirability = "list", fits = "list"))
 setGeneric(".nfp", function(object) standardGeneric(".nfp"))
 setMethod(".nfp", "facDesign", function(object) {
@@ -83,19 +72,16 @@ setMethod(".nfp", "facDesign", function(object) {
     if (is.list(x) && length(x[[1]]) > 0) {
         numAttr = length(attributes(x[[1]]))
         .numFac = length(x)
-        frameOut = data.frame(matrix(ncol = .numFac, nrow = (numAttr - 
-            1)))
+        frameOut = data.frame(matrix(ncol = .numFac, nrow = (numAttr - 1)))
         for (i in 1:(numAttr - 1)) {
             charVec = character(0)
             for (j in 1:.numFac) {
-                charVec = c(charVec, names(attributes(x[[1]])[i]), 
-                  "\t\t")
+                charVec = c(charVec, names(attributes(x[[1]])[i]), "\t\t")
                 frameOut[i, j] = attributes(x[[j]])[[i]]
             }
         }
         names(frameOut) = names(x)
-        rownames(frameOut) = names(attributes(x[[1]]))[1:(numAttr - 
-            1)]
+        rownames(frameOut) = names(attributes(x[[1]]))[1:(numAttr - 1)]
     }
     else {
         stop("no list given or length of list < 1")
@@ -111,8 +97,7 @@ setMethod("fits<-", "facDesign", function(x, value) {
     if (!identical(class(value), "lm")) 
         stop(paste(deparse(substitute(value)), "needs to an object of class lm"))
     if (!any(names(value$model)[1] == names(response(x)))) 
-        stop(paste("fitted response", names(value$model)[1], 
-            "could not be found in", deparse(substitute(x))))
+        stop(paste("fitted response", names(value$model)[1], "could not be found in", deparse(substitute(x))))
     listPos = length(x@fits) + 1
     yName = names(value$model)[1]
     isIn = (yName == names(x@fits))
@@ -157,8 +142,7 @@ setMethod(".clear", "facDesign", function(x) {
     x@response = data.frame()
     return(x)
 })
-setMethod("[", signature(x = "facDesign", i = "ANY", 
-    j = "ANY"), function(x, i, j) {
+setMethod("[", signature(x = "facDesign", i = "ANY", j = "ANY"), function(x, i, j) {
     return(as.data.frame(x)[i, j])
 })
 .helpSort = function(fdo, runOrd = TRUE) {
@@ -167,8 +151,7 @@ setMethod("[", signature(x = "facDesign", i = "ANY",
     out = fdo
     cube(out) = oldIndex[newIndex[1:nrow(cube)]]
 }
-setReplaceMethod("[", signature(x = "facDesign", i = "ANY", 
-    j = "ANY"), function(x, i, j, value) {
+setReplaceMethod("[", signature(x = "facDesign", i = "ANY", j = "ANY"), function(x, i, j, value) {
     print(paste("setting values via [", i, ",", j, " ]  is not supported"))
     print("Use response() to set the values of the response!")
     return(x)
@@ -194,11 +177,9 @@ setGeneric("types<-", function(x, value) standardGeneric("types<-"))
 setMethod("types", "facDesign", function(x) {
     return(sapply(factors(x), .type))
 })
-setReplaceMethod("types", "facDesign", function(x, 
-    value) {
+setReplaceMethod("types", "facDesign", function(x, value) {
     for (i in 1:length(x@factors)) {
-        if (!identical(value[i], "numeric") & !identical(value[i], 
-            "factor")) 
+        if (!identical(value[i], "numeric") & !identical(value[i], "factor")) 
             stop(paste(value[i], "\ttype of factor needs to be 'numeric' or 'factor'"))
         .type(x@factors[[i]]) = as.character(value[i])
     }
@@ -222,8 +203,7 @@ setMethod("highs", "facDesign", function(object) {
     }
     return(listOut)
 })
-setReplaceMethod("highs", "facDesign", function(object, 
-    value) {
+setReplaceMethod("highs", "facDesign", function(object, value) {
     for (i in seq(along = object@factors)) {
         .high(object@factors[[i]]) = value[i]
     }
@@ -238,8 +218,7 @@ setMethod("lows", "facDesign", function(object) {
     }
     return(listOut)
 })
-setReplaceMethod("lows", "facDesign", function(object, 
-    value) {
+setReplaceMethod("lows", "facDesign", function(object, value) {
     for (i in seq(along = object@factors)) {
         .low(object@factors[[i]]) = value[i]
     }
@@ -251,16 +230,14 @@ setMethod("cube", "facDesign", function(x) {
     out
 })
 setGeneric("cube<-", function(x, value) standardGeneric("cube<-"))
-setReplaceMethod("cube", "facDesign", function(x, 
-    value) {
+setReplaceMethod("cube", "facDesign", function(x, value) {
     x@cube <- value
     x
 })
 setGeneric("star", function(x) standardGeneric("star"))
 setGeneric("star<-", function(x, value) standardGeneric("star<-"))
 setMethod("star", "facDesign", function(x) x@star)
-setReplaceMethod("star", "facDesign", function(x, 
-    value) {
+setReplaceMethod("star", "facDesign", function(x, value) {
     DB = FALSE
     if (!is.data.frame(value)) 
         stop("data.frame must be provided!")
@@ -280,8 +257,7 @@ setReplaceMethod("star", "facDesign", function(x,
     standOrd(x) = data.frame(StandOrd = 1:(len + numNewRow))
     newRunOrd = data.frame()
     if (numNewRow > 0) {
-        newNums = data.frame(newNums = seq(max(oldRunOrd) + 1, 
-            max(oldRunOrd) + numNewRow, by = 1))
+        newNums = data.frame(newNums = seq(max(oldRunOrd) + 1, max(oldRunOrd) + numNewRow, by = 1))
         if (DB) 
             print(newNums)
         names(newNums) = names(oldRunOrd)
@@ -296,18 +272,15 @@ setReplaceMethod("star", "facDesign", function(x,
             print(newRunOrd)
     }
     else {
-        newRunOrd = data.frame(oldRunOrd[1:(lenFirst + nrow(newDf) + 
-            nrow(centerStar(x))), ])
+        newRunOrd = data.frame(oldRunOrd[1:(lenFirst + nrow(newDf) + nrow(centerStar(x))), ])
         names(newRunOrd) = names(oldRunOrd)
     }
     runOrd(x) = newRunOrd
-    naFrame = as.data.frame(matrix(rep(NA, times = ncol(oldResponse) * 
-        nrow(newDf)), ncol = ncol(oldResponse)))
+    naFrame = as.data.frame(matrix(rep(NA, times = ncol(oldResponse) * nrow(newDf)), ncol = ncol(oldResponse)))
     names(naFrame) = names(oldResponse)
     newResponse = data.frame(oldResponse[1:lenFirst, ])
     names(newResponse) = names(oldResponse)
-    restFrame = data.frame(oldResponse[-c(1:(lenFirst + nrow(oldDf))), 
-        ])
+    restFrame = data.frame(oldResponse[-c(1:(lenFirst + nrow(oldDf))), ])
     names(restFrame) = names(oldResponse)
     newResponse = rbind(newResponse, naFrame, restFrame)
     response(x) = newResponse
@@ -321,11 +294,9 @@ setReplaceMethod("star", "facDesign", function(x,
             print("TODO: BlockGen anpassen!")
         newBlockGen = data.frame(oldBlockGen[1:lenFirst, ])
         names(newBlockGen) = names(blockGen(x))
-        naFrameGen = as.data.frame(matrix(rep(NA, times = ncol(blockGen(x)) * 
-            nrow(newDf)), ncol = ncol(blockGen(x))))
+        naFrameGen = as.data.frame(matrix(rep(NA, times = ncol(blockGen(x)) * nrow(newDf)), ncol = ncol(blockGen(x))))
         names(naFrameGen) = names(oldBlockGen)
-        restBlockGen = data.frame(oldBlockGen[-c(1:(lenFirst + 
-            nrow(oldDf))), ])
+        restBlockGen = data.frame(oldBlockGen[-c(1:(lenFirst + nrow(oldDf))), ])
         names(restBlockGen) = names(oldBlockGen)
         newBlockGen = rbind(newBlockGen, naFrameGen, restBlockGen)
         if (DB) 
@@ -335,11 +306,9 @@ setReplaceMethod("star", "facDesign", function(x,
     oldBlock = block(x)
     newBlock = data.frame(oldBlock[1:lenFirst, ])
     names(newBlock) = names(oldBlock)
-    naFrame = as.data.frame(matrix(rep(max(newBlock) + 1, times = ncol(oldBlock) * 
-        nrow(newDf)), ncol = ncol(oldBlock)))
+    naFrame = as.data.frame(matrix(rep(max(newBlock) + 1, times = ncol(oldBlock) * nrow(newDf)), ncol = ncol(oldBlock)))
     names(naFrame) = names(oldBlock)
-    restBlock = data.frame(oldBlock[-c(1:(lenFirst + nrow(oldDf))), 
-        ])
+    restBlock = data.frame(oldBlock[-c(1:(lenFirst + nrow(oldDf))), ])
     names(restBlock) = names(oldBlock)
     newBlock = rbind(newBlock, naFrame, restBlock)
     block(x) = newBlock
@@ -349,8 +318,7 @@ setReplaceMethod("star", "facDesign", function(x,
 setGeneric("centerCube", function(x) standardGeneric("centerCube"))
 setGeneric("centerCube<-", function(x, value) standardGeneric("centerCube<-"))
 setMethod("centerCube", "facDesign", function(x) x@centerCube)
-setReplaceMethod("centerCube", "facDesign", function(x, 
-    value) {
+setReplaceMethod("centerCube", "facDesign", function(x, value) {
     DB = FALSE
     if (!is.data.frame(value)) 
         stop("data.frame must be provided!")
@@ -378,8 +346,7 @@ setReplaceMethod("centerCube", "facDesign", function(x,
     standOrd(x) = data.frame(StandOrd = 1:(len + numNewRow))
     newRunOrd = data.frame()
     if (numNewRow > 0) {
-        newNums = data.frame(newNums = seq(max(oldRunOrd) + 1, 
-            max(oldRunOrd) + numNewRow, by = 1))
+        newNums = data.frame(newNums = seq(max(oldRunOrd) + 1, max(oldRunOrd) + numNewRow, by = 1))
         names(newNums) = names(oldRunOrd)
         if (DB) {
             print("----")
@@ -399,11 +366,9 @@ setReplaceMethod("centerCube", "facDesign", function(x,
         runOrd(x) = newRunOrd
     }
     else {
-        newRunOrd = data.frame(oldRunOrd[1:(lenCube + nrow(newDf)), 
-            ])
+        newRunOrd = data.frame(oldRunOrd[1:(lenCube + nrow(newDf)), ])
         names(newRunOrd) = names(oldRunOrd)
-        restRunOrd = data.frame(oldRunOrd[-c(1:(lenCube + nrow(oldDf))), 
-            ])
+        restRunOrd = data.frame(oldRunOrd[-c(1:(lenCube + nrow(oldDf))), ])
         names(restRunOrd) = names(oldRunOrd)
         newRunOrd = rbind(newRunOrd, restRunOrd)
         if (DB) {
@@ -412,13 +377,11 @@ setReplaceMethod("centerCube", "facDesign", function(x,
         }
         runOrd(x) = newRunOrd
     }
-    naFrame = as.data.frame(matrix(rep(NA, times = ncol(oldResponse) * 
-        nrow(newDf)), ncol = ncol(oldResponse)))
+    naFrame = as.data.frame(matrix(rep(NA, times = ncol(oldResponse) * nrow(newDf)), ncol = ncol(oldResponse)))
     names(naFrame) = names(oldResponse)
     newResponse = data.frame(oldResponse[1:lenCube, ])
     names(newResponse) = names(oldResponse)
-    restResponse = data.frame(oldResponse[-c(1:(lenCube + nrow(oldDf))), 
-        ])
+    restResponse = data.frame(oldResponse[-c(1:(lenCube + nrow(oldDf))), ])
     names(restResponse) = names(oldResponse)
     newResponse = rbind(newResponse, naFrame, restResponse)
     if (DB) {
@@ -432,11 +395,9 @@ setReplaceMethod("centerCube", "facDesign", function(x,
             print("TODO: BlockGen Spalte(n) anpassen")
         newBlockGen = data.frame(oldBlockGen[1:lenCube, ])
         names(newBlockGen) = names(blockGen(x))
-        naFrameGen = as.data.frame(matrix(rep(NA, times = ncol(blockGen(x)) * 
-            nrow(newDf)), ncol = ncol(blockGen(x))))
+        naFrameGen = as.data.frame(matrix(rep(NA, times = ncol(blockGen(x)) * nrow(newDf)), ncol = ncol(blockGen(x))))
         names(naFrameGen) = names(oldBlockGen)
-        restFrame = data.frame(oldBlockGen[-c(1:(lenCube + nrow(oldDf))), 
-            ])
+        restFrame = data.frame(oldBlockGen[-c(1:(lenCube + nrow(oldDf))), ])
         names(restFrame) = names(blockGen(x))
         newBlockGen = rbind(newBlockGen, naFrameGen, restFrame)
         blockGen(x) = newBlockGen
@@ -446,10 +407,8 @@ setReplaceMethod("centerCube", "facDesign", function(x,
     oldBlock = block(x)
     newBlock = data.frame(oldBlock[1:lenCube, ])
     names(newBlock) = names(block(x))
-    naFrame = as.data.frame(matrix(rep(blockValues, times = nrow(newDf)/numBlocks), 
-        ncol = 1))
-    restFrame = as.data.frame(oldBlock[-c(1:(lenCube + nrow(oldDf))), 
-        ])
+    naFrame = as.data.frame(matrix(rep(blockValues, times = nrow(newDf)/numBlocks), ncol = 1))
+    restFrame = as.data.frame(oldBlock[-c(1:(lenCube + nrow(oldDf))), ])
     names(restFrame) = names(block(x))
     if (DB) 
         print(naFrame)
@@ -464,8 +423,7 @@ setGeneric("centerStar<-", function(x, value) standardGeneric("centerStar<-"))
 setMethod("centerStar", "facDesign", function(x) {
     x@centerStar
 })
-setReplaceMethod("centerStar", "facDesign", function(x, 
-    value) {
+setReplaceMethod("centerStar", "facDesign", function(x, value) {
     DB = FALSE
     if (!is.data.frame(value)) 
         stop("data.frame must be provided!")
@@ -486,8 +444,7 @@ setReplaceMethod("centerStar", "facDesign", function(x,
     newRunOrd = data.frame(oldRunOrd[1:lenRest, ])
     names(newRunOrd) = names(oldRunOrd)
     if (numNewRow > 0) {
-        newNums = data.frame(newNums = seq(max(oldRunOrd) + 1, 
-            max(oldRunOrd) + numNewRow, by = 1))
+        newNums = data.frame(newNums = seq(max(oldRunOrd) + 1, max(oldRunOrd) + numNewRow, by = 1))
         names(newNums) = names(oldRunOrd)
         restFrame = data.frame(oldRunOrd[-c(1:lenRest), ])
         names(restFrame) = names(oldRunOrd)
@@ -497,13 +454,11 @@ setReplaceMethod("centerStar", "facDesign", function(x,
         runOrd(x) = newRunOrd
     }
     else {
-        newRunOrd = data.frame(oldRunOrd[1:(lenRest + nrow(newDf)), 
-            ])
+        newRunOrd = data.frame(oldRunOrd[1:(lenRest + nrow(newDf)), ])
         names(newRunOrd) = names(oldRunOrd)
         runOrd(x) = newRunOrd
     }
-    naFrame = as.data.frame(matrix(rep(NA, times = ncol(oldResponse) * 
-        nrow(newDf)), ncol = ncol(oldResponse)))
+    naFrame = as.data.frame(matrix(rep(NA, times = ncol(oldResponse) * nrow(newDf)), ncol = ncol(oldResponse)))
     names(naFrame) = names(oldResponse)
     newResponse = data.frame(oldResponse[1:lenRest, ])
     names(newResponse) = names(response(x))
@@ -518,11 +473,9 @@ setReplaceMethod("centerStar", "facDesign", function(x,
         print("TODO: BlockGen Spalte(n) anpassen")
         newBlockGen = data.frame(oldBlockGen[1:lenRest, ])
         names(newBlockGen) = names(blockGen(x))
-        naFrameGen = as.data.frame(matrix(rep(NA, times = ncol(blockGen(x)) * 
-            nrow(newDf)), ncol = ncol(block(x))))
+        naFrameGen = as.data.frame(matrix(rep(NA, times = ncol(blockGen(x)) * nrow(newDf)), ncol = ncol(block(x))))
         names(naFrameGen) = names(oldBlockGen)
-        restBlockGen = data.frame(oldBlockGen[-c(1:(lenRest + 
-            nrow(oldDf))), ])
+        restBlockGen = data.frame(oldBlockGen[-c(1:(lenRest + nrow(oldDf))), ])
         names(restBlockGen) = names(oldBlockGen)
         newBlockGen = rbind(newBlockGen, naFrameGen, restBlockGen)
         if (DB) 
@@ -532,11 +485,9 @@ setReplaceMethod("centerStar", "facDesign", function(x,
     oldBlock = block(x)
     newBlock = data.frame(oldBlock[1:lenRest, ])
     names(newBlock) = names(block(x))
-    naFrame = as.data.frame(matrix(rep(max(block(x)[1:nrow(cube(x)), 
-        ]) + 1, times = ncol(block(x)) * nrow(newDf)), ncol = ncol(block(x))))
+    naFrame = as.data.frame(matrix(rep(max(block(x)[1:nrow(cube(x)), ]) + 1, times = ncol(block(x)) * nrow(newDf)), ncol = ncol(block(x))))
     names(naFrame) = names(oldBlock)
-    restBlock = data.frame(oldBlock[-c(1:(lenRest + nrow(oldDf))), 
-        ])
+    restBlock = data.frame(oldBlock[-c(1:(lenRest + nrow(oldDf))), ])
     names(restBlock) = names(oldBlock)
     newBlock = rbind(newBlock, naFrame, restBlock)
     block(x) = newBlock
@@ -555,15 +506,14 @@ setMethod("response", "facDesign", function(object) {
     names(out) = names(object@response)
     return(out)
 })
-setReplaceMethod("response", "facDesign", function(object, 
-    value) {
+setReplaceMethod("response", "facDesign", function(object, value) {
     index = order(runOrd(object))
     if (!is.vector(value) && !is.data.frame(value)) 
         stop("vector or data.frame expected!")
     if (is.vector(value) && (is.numeric(value) || is.na(value))) {
         if (nrow(response(object)) != length(value)) 
-            stop(paste("Number of rows for Design does not equal length of vector ", 
-                nrow(object), " != ", length(value), " "))
+            stop(paste("Number of rows for Design does not equal length of vector ", nrow(object), " != ", length(value), 
+                " "))
         object@response <- data.frame(value)
         object@response[index, ] <- value
         names(object@response) = deparse(substitute(value))
@@ -585,14 +535,13 @@ setGeneric("blockGen<-", function(object, value) {
 setMethod("blockGen", "facDesign", function(object) {
     return(object@blockGen)
 })
-setReplaceMethod("blockGen", "facDesign", function(object, 
-    value) {
+setReplaceMethod("blockGen", "facDesign", function(object, value) {
     if (!is.vector(value) && !is.data.frame(value)) 
         stop("vector or data.frame expected!")
     if (is.vector(value) && (is.numeric(value) || is.na(value))) {
         if (nrow(object) != length(value)) 
-            stop(paste("Number of rows for Design does not equal length of vector ", 
-                nrow(object), " != ", length(value), " "))
+            stop(paste("Number of rows for Design does not equal length of vector ", nrow(object), " != ", length(value), 
+                " "))
         object@blockGen <- as.data.frame(value)
         names(blockGen(object)) = deparse(substitute(value))
         object
@@ -612,14 +561,13 @@ setGeneric("block<-", function(object, value) {
 setMethod("block", "facDesign", function(object) {
     return(object@block)
 })
-setReplaceMethod("block", "facDesign", function(object, 
-    value) {
+setReplaceMethod("block", "facDesign", function(object, value) {
     if (!is.vector(value) && !is.data.frame(value)) 
         stop("vector or data.frame expected!")
     if (is.vector(value) && (is.numeric(value) || is.na(value))) {
         if (nrow(object) != length(value)) 
-            stop(paste("Number of rows for Design does not equal length of vector ", 
-                nrow(object), " != ", length(value), " "))
+            stop(paste("Number of rows for Design does not equal length of vector ", nrow(object), " != ", length(value), 
+                " "))
         object@block <- as.data.frame(value)
         names(block(object)) = deparse(substitute(value))
         object
@@ -633,32 +581,28 @@ setReplaceMethod("block", "facDesign", function(object,
 setGeneric("standOrd", function(x) standardGeneric("standOrd"))
 setGeneric("standOrd<-", function(x, value) standardGeneric("standOrd<-"))
 setMethod("standOrd", "facDesign", function(x) x@standardOrder)
-setReplaceMethod("standOrd", "facDesign", function(x, 
-    value) {
+setReplaceMethod("standOrd", "facDesign", function(x, value) {
     x@standardOrder <- value
     x
 })
 setGeneric("runOrd", function(x) standardGeneric("runOrd"))
 setGeneric("runOrd<-", function(x, value) standardGeneric("runOrd<-"))
 setMethod("runOrd", "facDesign", function(x) x@runOrder)
-setReplaceMethod("runOrd", "facDesign", function(x, 
-    value) {
+setReplaceMethod("runOrd", "facDesign", function(x, value) {
     x@runOrder <- value
     x
 })
 setGeneric(".generators", function(object) standardGeneric(".generators"))
 setGeneric(".generators<-", function(x, value) standardGeneric(".generators<-"))
 setMethod(".generators", "facDesign", function(object) object@generator)
-setReplaceMethod(".generators", "facDesign", function(x, 
-    value) {
+setReplaceMethod(".generators", "facDesign", function(x, value) {
     x@generator <- value
     x
 })
 setGeneric("factors", function(x) standardGeneric("factors"))
 setMethod("factors", "facDesign", function(x) x@factors)
 setGeneric("factors<-", function(x, value) standardGeneric("factors<-"))
-setReplaceMethod("factors", "facDesign", function(x, 
-    value) {
+setReplaceMethod("factors", "facDesign", function(x, value) {
     if (length(value) != dim(cube(x))[2]) 
         stop("\nNumber of factors doesn't match with number of columns for factorial Design\n")
     x@factors <- value
@@ -667,13 +611,11 @@ setReplaceMethod("factors", "facDesign", function(x,
 setMethod("names", "facDesign", function(x) {
     return(sapply(x@factors, names))
 })
-setReplaceMethod("names", "facDesign", function(x, 
-    value) {
+setReplaceMethod("names", "facDesign", function(x, value) {
     for (i in 1:length(x@factors)) names(x@factors[[i]]) = as.character(value[i])
     x
 })
-setMethod("as.data.frame", "facDesign", function(x, 
-    row.names = NULL, optional = FALSE, ...) {
+setMethod("as.data.frame", "facDesign", function(x, row.names = NULL, optional = FALSE, ...) {
     if (!is.null(cube(x))) {
         frameOut = cube(x)
     }
@@ -702,8 +644,7 @@ setMethod("as.data.frame", "facDesign", function(x,
     if (nrow(frameOut) == nrow(response(x))) 
         frameOut = cbind(frameOut, x@response)
     else {
-        temp = as.data.frame(matrix(NA, nrow = nrow(frameOut), 
-            ncol = ncol(response(x))))
+        temp = as.data.frame(matrix(NA, nrow = nrow(frameOut), ncol = ncol(response(x))))
         names(temp) = names(response(x))
         frameOut = cbind(frameOut, temp)
     }
@@ -711,8 +652,7 @@ setMethod("as.data.frame", "facDesign", function(x,
     out = frameOut[runIndex, ]
     return(out)
 })
-as.data.frame.facDesign = function(x, row.names = NULL, 
-    optional = FALSE, ...) {
+as.data.frame.facDesign = function(x, row.names = NULL, optional = FALSE, ...) {
     if (!is.null(cube(x))) {
         frameOut = cube(x)
     }
@@ -741,8 +681,7 @@ as.data.frame.facDesign = function(x, row.names = NULL,
     if (nrow(frameOut) == nrow(response(x))) 
         frameOut = cbind(frameOut, x@response)
     else {
-        temp = as.data.frame(matrix(NA, nrow = nrow(frameOut), 
-            ncol = ncol(response(x))))
+        temp = as.data.frame(matrix(NA, nrow = nrow(frameOut), ncol = ncol(response(x))))
         names(temp) = names(response(x))
         frameOut = cbind(frameOut, temp)
     }
@@ -750,24 +689,22 @@ as.data.frame.facDesign = function(x, row.names = NULL,
     out = frameOut[runIndex, ]
     return(frameOut)
 }
-setMethod("show", signature(object = "facDesign"), 
-    function(object) {
-        runIndex = order(runOrd(object))
-        print(format(as.data.frame(object), digits = 4))
-        invisible(as.data.frame(object))
-    })
-setMethod("summary", signature(object = "facDesign"), 
-    function(object) {
-        doeFactors = factors(object)
-        cat("Information about the factors:\n\n")
-        .nfp(object)
-        cat("\n-----------\n")
-        print(as.data.frame(object))
-        cat("\n---------\n\n")
-        identity(object)
-        cat("\n")
-        invisible(as.data.frame(object))
-    })
+setMethod("show", signature(object = "facDesign"), function(object) {
+    runIndex = order(runOrd(object))
+    print(format(as.data.frame(object), digits = 4))
+    invisible(as.data.frame(object))
+})
+setMethod("summary", signature(object = "facDesign"), function(object) {
+    doeFactors = factors(object)
+    cat("Information about the factors:\n\n")
+    .nfp(object)
+    cat("\n-----------\n")
+    print(as.data.frame(object))
+    cat("\n---------\n\n")
+    identity(object)
+    cat("\n")
+    invisible(as.data.frame(object))
+})
 .identityOld = function(x, DB = FALSE) {
     identityList = vector(mode = "list", length = 0)
     varName = deparse(substitute(x))
@@ -804,10 +741,8 @@ setMethod("summary", signature(object = "facDesign"),
                 a = a + 1
                 identityList[[a]] = ident
                 charIdentity = character(0)
-                for (j in 1:length(ident)) charIdentity = c(charIdentity, 
-                  names(x)[ident[j]])
-                names(identityList)[[a]] = paste(charIdentity, 
-                  sep = "", collapse = "")
+                for (j in 1:length(ident)) charIdentity = c(charIdentity, names(x)[ident[j]])
+                names(identityList)[[a]] = paste(charIdentity, sep = "", collapse = "")
             }
             if (DB) {
                 cat("ident: ", ident, "\n")
@@ -819,15 +754,12 @@ setMethod("summary", signature(object = "facDesign"),
     cat("Defining relations:\n")
     if (length(identityList) > 0) {
         for (i in 1:length(identityList)) {
-            identLen = length((strsplit(names(identityList)[i], 
-                split = character(0))[[1]]))
+            identLen = length((strsplit(names(identityList)[i], split = character(0))[[1]]))
             if (length(resolution) == 0 || identLen > resolution) 
                 resolution = c(resolution, identLen)
-            cat("I = ", names(identityList)[i], "\t\tColumns:", 
-                identityList[[i]], "\n")
+            cat("I = ", names(identityList)[i], "\t\tColumns:", identityList[[i]], "\n")
         }
-        cat("\nResolution: ", as.character(as.roman(min(resolution))), 
-            "\n")
+        cat("\nResolution: ", as.character(as.roman(min(resolution))), "\n")
     }
     invisible(identityList)
 }
@@ -847,8 +779,7 @@ setMethod("summary", signature(object = "facDesign"),
             }
             else {
                 X1 = cbind(X1, apply(X[, index], 1, prod))
-                nameVec = c(nameVec, paste(temp[, j], sep = "", 
-                  collapse = ""))
+                nameVec = c(nameVec, paste(temp[, j], sep = "", collapse = ""))
             }
         }
         X1 = data.frame(X1)
@@ -857,38 +788,34 @@ setMethod("summary", signature(object = "facDesign"),
     return(X1)
 }
 setGeneric("identity")
-setMethod("identity", signature(x = "facDesign"), 
-    function(x) {
-        identity = character(0)
-        identityList = vector(mode = "list", length = 0)
-        resolution = numeric(0)
-        temp = NULL
-        A = aliasTable(x, show = FALSE)
-        if (any(dim(A) == 0)) 
-            return(identityList)
-        temp = as.matrix(A["Identity", ])
-        boolTemp = apply(temp, 2, as.logical)
-        identity = row.names(temp)[boolTemp[, 1]]
-        if (length(identity) > 0) {
-            charList = strsplit(toupper(identity), split = "")
-            identityList = lapply(charList, match, .NAMES[1:25])
-            names(identityList) = identity
+setMethod("identity", signature(x = "facDesign"), function(x) {
+    identity = character(0)
+    identityList = vector(mode = "list", length = 0)
+    resolution = numeric(0)
+    temp = NULL
+    A = aliasTable(x, show = FALSE)
+    if (any(dim(A) == 0)) 
+        return(identityList)
+    temp = as.matrix(A["Identity", ])
+    boolTemp = apply(temp, 2, as.logical)
+    identity = row.names(temp)[boolTemp[, 1]]
+    if (length(identity) > 0) {
+        charList = strsplit(toupper(identity), split = "")
+        identityList = lapply(charList, match, .NAMES[1:25])
+        names(identityList) = identity
+    }
+    cat("Defining relations:\n")
+    if (length(identityList) > 0) {
+        for (i in 1:length(identityList)) {
+            identLen = length((strsplit(names(identityList)[i], split = character(0))[[1]]))
+            if (length(resolution) == 0 || identLen > resolution) 
+                resolution = c(resolution, identLen)
+            cat("I = ", names(identityList)[i], "\t\tColumns:", identityList[[i]], "\n")
         }
-        cat("Defining relations:\n")
-        if (length(identityList) > 0) {
-            for (i in 1:length(identityList)) {
-                identLen = length((strsplit(names(identityList)[i], 
-                  split = character(0))[[1]]))
-                if (length(resolution) == 0 || identLen > resolution) 
-                  resolution = c(resolution, identLen)
-                cat("I = ", names(identityList)[i], "\t\tColumns:", 
-                  identityList[[i]], "\n")
-            }
-            cat("\nResolution: ", as.character(as.roman(min(resolution))), 
-                "\n")
-        }
-        invisible(identityList)
-    })
+        cat("\nResolution: ", as.character(as.roman(min(resolution))), "\n")
+    }
+    invisible(identityList)
+})
 confounds = function(x, depth = 2) {
     DB = FALSE
     varName = deparse(substitute(x))
@@ -922,16 +849,11 @@ confounds = function(x, depth = 2) {
                 isect = intersect(ident, combMat[, i])
                 conf = setdiff(ident, isect)
                 conf = sort(c(conf, setdiff(combMat[, i], isect)))
-                effect1 = c(effect1, paste(sort(names(x)[as.numeric((combMat[, 
-                  i]))]), sep = "", collapse = ""))
-                effect2 = c(effect2, paste(sort(names(x)[conf]), 
-                  sep = "", collapse = ""))
+                effect1 = c(effect1, paste(sort(names(x)[as.numeric((combMat[, i]))]), sep = "", collapse = ""))
+                effect2 = c(effect2, paste(sort(names(x)[conf]), sep = "", collapse = ""))
                 if (DB) {
-                  cat("Effect(s) ", as.numeric((combMat[, i])), 
-                    " aliased with Effect(s)", conf, "\n")
-                  cat("Effect(s)", names(x)[as.numeric((combMat[, 
-                    i]))], " aliased with Effects ", names(x)[conf], 
-                    "\n")
+                  cat("Effect(s) ", as.numeric((combMat[, i])), " aliased with Effect(s)", conf, "\n")
+                  cat("Effect(s)", names(x)[as.numeric((combMat[, i]))], " aliased with Effects ", names(x)[conf], "\n")
                 }
             }
         }
@@ -944,8 +866,7 @@ confounds = function(x, depth = 2) {
         dupIndex = numeric(0)
     for (i in 1:length(effect1)) {
         if (DB) {
-            cat("i: ", i, "\tlength(effect1): ", length(effect1), 
-                "\n")
+            cat("i: ", i, "\tlength(effect1): ", length(effect1), "\n")
             cat("effect 1 : ", effect1, "\n")
         }
         if (i > length(effect1)) 
@@ -967,19 +888,15 @@ confounds = function(x, depth = 2) {
     }
     cat("\nAlias Structure:\n")
     for (i in 1:length(effect1)) {
-        if ((length(strsplit(effect1[i], split = character(0))[[1]]) <= 
-            depth) && (length(strsplit(effect2[i], split = character(0))[[1]]) <= 
+        if ((length(strsplit(effect1[i], split = character(0))[[1]]) <= depth) && (length(strsplit(effect2[i], split = character(0))[[1]]) <= 
             depth)) 
-            cat(effect1[i], "\tis confounded with\t", effect2[i], 
-                "\n")
+            cat(effect1[i], "\tis confounded with\t", effect2[i], "\n")
         if (identical(depth, "all")) 
-            cat(effect1[i], "\tis confounded with\t", effect2[i], 
-                "\n")
+            cat(effect1[i], "\tis confounded with\t", effect2[i], "\n")
     }
     invisible(effect1)
 }
-fracDesign = function(k = 3, gen = NULL, replicates = 1, 
-    blocks = 1, centerCube = 0, random.seed = 1234) {
+fracDesign = function(k = 3, gen = NULL, replicates = 1, blocks = 1, centerCube = 0, random.seed = 1234) {
     DB = FALSE
     if (!is.numeric(random.seed)) 
         stop("random.seed needs to be numeric")
@@ -991,8 +908,7 @@ fracDesign = function(k = 3, gen = NULL, replicates = 1,
         stop("replicates need to >= 0")
     N <- 2^k
     X <- matrix(NA, nrow = N, ncol = k)
-    for (j in 1:k) X[, j] <- rep(sort(rep(c(-1, 1), N/2^j)), 
-        2^(j - 1))
+    for (j in 1:k) X[, j] <- rep(sort(rep(c(-1, 1), N/2^j)), 2^(j - 1))
     X <- X[, ncol(X):1]
     if (is.null(gen)) {
         X = as.data.frame(X)
@@ -1062,13 +978,11 @@ fracDesign = function(k = 3, gen = NULL, replicates = 1,
             allowedChars = c(.NAMES[1:26], letters[1:26], "=")
             for (j in 1:length(chars)) {
                 if (chars[j] %in% allowedChars) {
-                  if ((chars[j] == "=") & (length(numVec) != 
-                    1)) 
+                  if ((chars[j] == "=") & (length(numVec) != 1)) 
                     stop("check position of \"=\" in generators!")
                   if (chars[j] != "=") {
                     charVec = c(charVec, toupper(chars[j]))
-                    numVec = c(numVec, numCharVec[names(numCharVec) == 
-                      toupper(chars[j])])
+                    numVec = c(numVec, numCharVec[names(numCharVec) == toupper(chars[j])])
                   }
                 }
             }
@@ -1093,8 +1007,7 @@ fracDesign = function(k = 3, gen = NULL, replicates = 1,
         for (i in seq(along = listGen)) {
             ind <- trunc(listGen[[i]])
             if (any(abs(ind) > k)) 
-                stop(paste("generator:", paste(ind[1], "=", paste(ind[-1], 
-                  collapse = "*")), "includes undefined columns"))
+                stop(paste("generator:", paste(ind[1], "=", paste(ind[-1], collapse = "*")), "includes undefined columns"))
             x <- rep(sign(ind[1]), N)
             for (j in ind[-1]) x <- x * X[, j]
             X[, abs(ind[1])] <- x
@@ -1127,8 +1040,7 @@ fracDesign = function(k = 3, gen = NULL, replicates = 1,
         print("yes")
     if (DB) 
         print("aha")
-    numRows = nrow(cube(DesignOut)) + nrow(star(DesignOut)) + 
-        nrow(centerStar(DesignOut)) + nrow(centerCube(DesignOut))
+    numRows = nrow(cube(DesignOut)) + nrow(star(DesignOut)) + nrow(centerStar(DesignOut)) + nrow(centerCube(DesignOut))
     if (DB) {
         print(numRows)
         print("response")
@@ -1136,16 +1048,14 @@ fracDesign = function(k = 3, gen = NULL, replicates = 1,
     DesignOut@response = data.frame(y = rep(NA, numRows))
     if (DB) 
         print("response")
-    standardOrder = data.frame(matrix(data = 1:numRows, nrow = numRows, 
-        ncol = 1))
+    standardOrder = data.frame(matrix(data = 1:numRows, nrow = numRows, ncol = 1))
     names(standardOrder) = "StandOrder"
     standardOrder
     standOrd(DesignOut) = standardOrder
     if (DB) 
         print("1")
     set.seed(random.seed)
-    runOrder = as.data.frame(standardOrder[sample(1:numRows), 
-        ])
+    runOrder = as.data.frame(standardOrder[sample(1:numRows), ])
     if (DB) 
         print("2")
     names(runOrder) = "RunOrder"
@@ -1157,16 +1067,13 @@ fracDesign = function(k = 3, gen = NULL, replicates = 1,
         block(DesignOut) = Block
     }
     if (centerCube >= 1) {
-        temp = data.frame(matrix(rep(0, centerCube * k), ncol = k, 
-            nrow = centerCube))
+        temp = data.frame(matrix(rep(0, centerCube * k), ncol = k, nrow = centerCube))
         names(temp) = names(frameOut)
         centerCube(DesignOut) = temp
     }
     return(DesignOut)
 }
-facDesign = function(k = 3, replicates = 1, blocks = 1, 
-    centerCube = 0) {
-    frameOut = fracDesign(k = k, gen = NULL, replicates = replicates, 
-        blocks = 1, centerCube = centerCube)
+facDesign = function(k = 3, replicates = 1, blocks = 1, centerCube = 0) {
+    frameOut = fracDesign(k = k, gen = NULL, replicates = replicates, blocks = 1, centerCube = centerCube)
     return(frameOut)
 } 
